#Datakitchen API Tools

Python library for interacting with the Datakitchen API

##Install

`pip install datakitchen_api_tools` 

##Using the library

###Establishing a connection

Create a DKConnection object:

`conn = DKConnection("cloud.datakitchen.io", '<USERNAME>', '<PASSWORD>')`


###Methods


